#ifndef HC595x2_h
#define HC595x2_h

#include <Arduino.h>

class HC595x2 {
public:
    // Constructor
    HC595x2(int latchPin, int clockPin, int dataPin);

    // Member functions
    void setDelay(int msDelay);

    void right();
    void knightRider();
    void left();
    void on();
    void off();
    void blink();

private:
    // Member variables
    int latchPin;
    int clockPin;
    int dataPin;
    int msDelay;
    int currentStep;
    int direction;
    bool currentState;
    unsigned long lastExecuted;

    // Member functions
    void shiftOut(byte dataOut);
    void setValue(byte led1, byte led2);
    bool shouldRun();
    void finishRun(int parts, int direction);
    void run(int parts, int direction);

    // Each element of the array represents the state of 8 LEDs controlled by one of the 595 chips
    // E.g. the first element of LED1 is 3 which is binary 11000000 so the first 2 LEDs are on
    // In each case 2 LEDs are on at any time 
    // LED1[30] = {0b11000000,0b01100000,0b00110000,0b00011000,0b00001100,0b00000110,0b00000011,0b00000001 ...etc...
    // LED2[30] = {0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b00000000,0b10000000 ...etc...
    byte LED1[30] = {3,6,12,24,48,96,192,128,0,0, 0, 0, 0, 0,  0, 0, 0, 0, 0,0,0,128,192,96,48,24,12,6,3};
    byte LED2[30] = {0,0, 0, 0, 0, 0,  0,  1,3,6,12,24,48,96,192,96,48,24,12,6,3,  1,  0, 0, 0, 0, 0,0,0};

};

#endif